# Geographical XGBoost
An implementation of XGBoost designed for geographical analysis.

# Installation
pip install geoxgboost

# Tutorial
A comprehensive tutorial is available on GitHub that demonstrates how to:
1.   Create a project in PyCharm
2.   Install geoxgboost
3.   Run the code using demo data

Here's the link to the tutorial:
https://github.com/geogreko/DemoGXGBoost/tree/main 

# Demo data
Boston housing dataset

The following files are included in the GitHub repository:

1.    Coords.csv: Coordinates of the spatial units.
2.    Data.csv: Dependent and independent variables.
3.    DataDescription.xlsx: Data description.
4.    GXGB_call_demo.py: Python script to analyze the Boston housing dataset.
5.    PredictCoords.csv: Coordinates of the spatial units for prediction.
6.    PredictData.csv: Values of the independent variables for the spatial units where predictions will be made.
7.    Tutorial_geoxgboost.pdf: A guide for using the demo.

# How to cite
Grekousis G. (2025). Geographical-XGBoost: A new ensemble model for spatially local regression based on gradient-boosted trees. _Journal of Geographical Systems_. 
https://doi.org/10.1007/s10109-025-00465-4


